@@ -37,6 +37,7 @@ for which a new license (GPL+exception) is in place.
 #include <qtable.h>
 #include <qtooltip.h>
 
+#include "commonstrings.h"
 #include "pagestructs.h"
 
 
@@ -70,7 +71,7 @@ void DocSections::setup(const DocumentSectionMap docSections, int maxPageIndex)
 	localSections=docSections;
 	m_maxpageindex=maxPageIndex;
 	
-	styles << tr("1, 2, 3, ...") << tr("i, ii, iii, ...") << tr("I, II, III, ...") << tr("a, b, c, ...") << tr("A, B, C, ...");
+	styles << tr("1, 2, 3, ...") << tr("i, ii, iii, ...") << tr("I, II, III, ...") << tr("a, b, c, ...") << tr("A, B, C, ...") << CommonStrings::tr_None;
 	
 	updateTable();
 }
@@ -98,7 +99,10 @@ void DocSections::updateTable()
 		//Style
 		QComboTableItem *item5 = new QComboTableItem(sectionsTable, styles);
 		sectionsTable->setItem(row, i++, item5);
-		item5->setCurrentItem((*it).type);
+		if ((*it).type==Type_None)
+			item5->setCurrentItem(styles.count()-1);
+		else
+			item5->setCurrentItem((*it).type);
 		//Start Page Number
 		QTableItem *item6 = new QTableItem(sectionsTable, QTableItem::WhenCurrent, QString::number((*it).sectionstartindex));
 		sectionsTable->setItem(row, i++, item6);
@@ -119,6 +123,8 @@ void DocSections::updateTable()
 void DocSections::tableItemChanged( int row, int col )
 {
 	bool outOfRange=false;
+	uint newDocPageSpec;
+
 	switch (col)
 	{
 	case 0:
@@ -128,36 +134,27 @@ void DocSections::tableItemChanged( int row, int col )
 		localSections[row].active=static_cast<QCheckTableItem*>(sectionsTable->item(row, col))->isChecked();
 		break;
 	case 2:
-		localSections[row].fromindex=sectionsTable->text(row, col).toUInt();
-		if (localSections[row].fromindex<1)
-		{
-			localSections[row].fromindex=0;
-			outOfRange=true;
-		}
-		else
-		if (localSections[row].fromindex>m_maxpageindex)
-		{
-			localSections[row].fromindex=m_maxpageindex;
-			outOfRange=true;
-		}
-		else
-			--localSections[row].fromindex;
-		break;
 	case 3:
-		localSections[row].toindex=sectionsTable->text(row, col).toUInt();
-		if (localSections[row].toindex<1)
+		// Validate to/from page specification before conversion to an index
+		//!!!	There is still a problem here if m_maxpageindex == MAX_UINT ;)
+		newDocPageSpec=sectionsTable->text(row, col).toUInt();
+		if (newDocPageSpec==0)
 		{
-			localSections[row].toindex=0;
+			newDocPageSpec=1;
 			outOfRange=true;
 		}
 		else
-		if (localSections[row].toindex>m_maxpageindex)
+		if (newDocPageSpec>m_maxpageindex+1)
 		{
-			localSections[row].toindex=m_maxpageindex;
+			newDocPageSpec=m_maxpageindex+1;
 			outOfRange=true;
 		}
+		// Now, since newDocPageSpec >= 1, convert to index
+		--newDocPageSpec;
+		if (col==2)
+			localSections[row].fromindex=newDocPageSpec;
 		else
-			--localSections[row].toindex;
+			localSections[row].toindex=newDocPageSpec;
 		break;
 	case 4:
 		{
@@ -165,8 +162,11 @@ void DocSections::tableItemChanged( int row, int col )
 			if (qcti!=NULL)
 			{
 				uint index=qcti->currentItem();
-				if (index<styles.count())
+				if (index<styles.count()-1)
 					localSections[row].type=(DocumentSectionType)index;
+				else 
+					if (index==styles.count()-1)
+					localSections[row].type=Type_None;
 			}
 		}
 		break;
@@ -205,8 +205,8 @@ void DocSections::addEntry()
 		uint count=localSections.count();
 		blank.number=count;
 		blank.name=QString::number(count);
-		blank.fromindex=m_maxpageindex;
-		blank.toindex=m_maxpageindex;
+		blank.fromindex=m_maxpageindex+1;
+		blank.toindex=m_maxpageindex+1;
 		blank.type=Type_1_2_3;
 		blank.sectionstartindex=1;
 		blank.reversed=false;
@@ -230,8 +230,8 @@ void DocSections::addEntry()
 				struct DocumentSection blank;
 				blank.number=++i;
 				blank.name=QString::number(i);
-				blank.fromindex=(*it).toindex+1;
-				blank.toindex=(*it).toindex+2;
+				blank.fromindex=(*it).toindex+1+1;
+				blank.toindex=(*it).toindex+2+1;
 				blank.type=Type_1_2_3;
 				blank.sectionstartindex=1;
 				blank.reversed=false;
