@@ -8,9 +8,9 @@ for which a new license (GPL+exception) is in place.
 #define TEXTFILTER_H
 
 #include "pluginapi.h"
-#include <scribus.h>
+#include "scribus.h"
 #include <prefscontext.h>
-#include <gtwriter.h>
+#include "gtwriter.h"
 #include "tffilter.h"
 
 extern "C" PLUGIN_API void GetText(QString filename, QString encoding, bool textOnly, gtWriter *writer);
