@@ -35,12 +35,13 @@ for which a new license (GPL+exception) is in place.
 
 #include "scribusapp.h"
 #include "scribusapp.moc"
-#include "scribus.h"
+#include "scribuscore.h"
 #include "scpaths.h"
 #include "prefsfile.h"
 #include "langmgr.h"
 #include "prefsmanager.h"
 #include "commonstrings.h"
+#include "upgradechecker.h"
 
 #if defined(_WIN32)
 #include <windows.h>
@@ -51,22 +52,28 @@ for which a new license (GPL+exception) is in place.
 #define ARG_LANG "--lang"
 #define ARG_AVAILLANG "--langs-available"
 #define ARG_NOSPLASH "--no-splash"
+#define ARG_NEVERSPLASH "--never-splash"
 #define ARG_NOGUI "--no-gui"
 #define ARG_DISPLAY "--display"
 #define ARG_FONTINFO "--font-info"
+#define ARG_PROFILEINFO "--profile-info"
 #define ARG_SWAPDIABUTTONS "--swap-buttons"
 #define ARG_PREFS "--prefs"
+#define ARG_UPGRADECHECK "--upgradecheck"
 
 #define ARG_VERSION_SHORT "-v"
 #define ARG_HELP_SHORT "-h"
 #define ARG_LANG_SHORT "-l"
 #define ARG_AVAILLANG_SHORT "-la"
 #define ARG_NOSPLASH_SHORT "-ns"
+#define ARG_NEVERSPLASH_SHORT "-nns"
 #define ARG_NOGUI_SHORT "-g"
 #define ARG_DISPLAY_SHORT "-d"
 #define ARG_FONTINFO_SHORT "-fi"
+#define ARG_PROFILEINFO_SHORT "-pi"
 #define ARG_SWAPDIABUTTONS_SHORT "-sb"
 #define ARG_PREFS_SHORT "-pr"
+#define ARG_UPGRADECHECK_SHORT "-u"
 
 // Qt wants -display not --display or -d
 #define ARG_DISPLAY_QT "-display"
@@ -76,15 +83,16 @@ extern const char ARG_CONSOLE[] =  "--console";
 extern const char ARG_CONSOLE_SHORT[] = "-cl";
 
 extern ScribusQApp* ScQApp;
+extern ScribusCore* ScCore;
 
 bool ScribusQApp::useGUI=false;
 
-ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv)
+ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv),
+	lang(""),
+	GUILang("")
 {
 	ScQApp=this;
-	ScMW=NULL;
-	lang="";
-	GUILang="";
+	ScCore=NULL;
 }
 
 ScribusQApp::~ScribusQApp()
@@ -102,13 +110,15 @@ void ScribusQApp::initLang()
 
 void ScribusQApp::parseCommandLine()
 {
-	showSplash=true;
-	QString arg = "";
+	showSplash=!neverSplashExists();
+	QString arg("");
 	bool usage=false;
 	bool header=false;
 	bool availlangs=false;
 	bool version=false;
+	bool runUpgradeCheck=false;
 	showFontInfo=false;
+	showProfileInfo=false;
 	swapDialogButtonOrder=false;
 
 	//Parse for command line information options, and lang
@@ -128,6 +138,9 @@ void ScribusQApp::parseCommandLine()
 		} else if (arg == ARG_AVAILLANG || arg == ARG_AVAILLANG_SHORT) {
 			header=true;
 			availlangs=true;
+		} else if (arg == ARG_UPGRADECHECK || arg == ARG_UPGRADECHECK_SHORT) {
+			header=true;
+			runUpgradeCheck=true;
 		}
 	}
 	//Init translations
@@ -141,6 +154,12 @@ void ScribusQApp::parseCommandLine()
 		showAvailLangs();
 	if (usage)
 		showUsage();
+	if (runUpgradeCheck)
+	{
+		UpgradeChecker uc;
+		bool error=uc.fetch();
+		uc.show(error);
+	}
 	//Dont run the GUI init process called from main.cpp, and return
 	if (!header)
 		useGUI=true;
@@ -156,10 +175,16 @@ void ScribusQApp::parseCommandLine()
 			continue;
 		} else if (arg == ARG_NOSPLASH || arg == ARG_NOSPLASH_SHORT) {
 			showSplash = false;
+		}
+		else if (arg == ARG_NEVERSPLASH || arg == ARG_NEVERSPLASH_SHORT) {
+			showSplash = false;
+			neverSplash(true);
 		} else if (arg == ARG_NOGUI || arg == ARG_NOGUI_SHORT) {
 			useGUI=false;
 		} else if (arg == ARG_FONTINFO || arg == ARG_FONTINFO_SHORT) {
 			showFontInfo=true;
+		} else if (arg == ARG_PROFILEINFO || arg == ARG_PROFILEINFO_SHORT) {
+			showProfileInfo=true;
 		} else if (arg == ARG_SWAPDIABUTTONS || arg == ARG_SWAPDIABUTTONS_SHORT) {
 			swapDialogButtonOrder=true;
 		} else if ((arg == ARG_DISPLAY || arg==ARG_DISPLAY_SHORT || arg==ARG_DISPLAY_QT) && ++i < argc()) {
@@ -203,39 +228,17 @@ void ScribusQApp::parseCommandLine()
 
 int ScribusQApp::init()
 {
+	m_ScCore=new ScribusCore();
+	Q_CHECK_PTR(m_ScCore);
+	if (!m_ScCore)
+		return EXIT_FAILURE;
+	ScCore=m_ScCore;
 	processEvents();
+	ScCore->init(useGUI, swapDialogButtonOrder, file);
+	int retVal=EXIT_SUCCESS;
 	if (useGUI)
-	{
-		scribus = new ScribusMainWindow();
-		ScMW=scribus;
-		if (!scribus)
-			exit(EXIT_FAILURE);
-		int scribusRetVal = scribus->initScribus(showSplash, showFontInfo, lang, prefsUserFile);
-		if (scribusRetVal == 1)
-			return(EXIT_FAILURE);
-
-		setMainWidget(scribus);
-		connect(this, SIGNAL(lastWindowClosed()), this, SLOT(quit()));
-
-		scribus->show();
-		scribus->ShowSubs();
-
-		if (!file.isEmpty())
-			scribus->loadDoc(file);
-		else
-		{
-			if (PrefsManager::instance()->appPrefs.showStartupDialog)
-				scribus->startUpDialog();
-			else
-				scribus->setFocus();
-		}
-
-		// A hook for plug-ins and scripts to trigger on. Some plugins and scripts
-		// require the app to be fully set up (in particular, the main window to be
-		// built and shown) before running their setup.
-		emit appStarted();
-	}
-	return EXIT_SUCCESS;
+		retVal=ScCore->startGUI(showSplash, showFontInfo, showProfileInfo, lang, prefsUserFile);
+	return retVal;
 }
 
 QStringList ScribusQApp::getLang(QString lang)
@@ -247,7 +250,7 @@ QStringList ScribusQApp::getLang(QString lang)
 		langs.push_back(lang);
 
 	//add in user preferences lang, only overridden by lang command line option
-	QString Pff = QDir::convertSeparators(QDir::homeDirPath()+"/.scribus");
+	QString Pff = QDir::convertSeparators(ScPaths::getApplicationDataDir());
 	QFileInfo Pffi = QFileInfo(Pff);
 	if (Pffi.exists())
 	{
@@ -256,7 +259,7 @@ QStringList ScribusQApp::getLang(QString lang)
 			PrefsPfad = Pff;
 		else
 			PrefsPfad = QDir::homeDirPath();
-		QString prefsXMLFile=QDir::convertSeparators(PrefsPfad + "/prefs13.xml");
+		QString prefsXMLFile=QDir::convertSeparators(PrefsPfad + "/prefs134.xml");
 		QFileInfo infoPrefsFile(prefsXMLFile);
 		if (infoPrefsFile.exists())
 		{
@@ -269,6 +272,7 @@ QStringList ScribusQApp::getLang(QString lang)
 						langs.push_back(prefslang);
 				}
 			}
+			delete prefsFile;
 		}
 	}
 
@@ -325,14 +329,14 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 
 	bool loaded = false;
 	QString lang;
-	for (QStringList::const_iterator it = langs.constBegin(); it != langs.constEnd() && !loaded; ++it) {
+	for (QStringList::const_iterator it = langs.constBegin(); it != langs.constEnd() && !loaded; ++it) 
+	{
 		lang=(*it).left(5);
 		if (lang == "en")
 			break;
 		else if (loaded = trans->load(QString(path + '.' + lang), "."))
 			loaded = true;
 	}
-
 	if (loaded)
 	{
 		installTranslator(trans);
@@ -370,7 +374,7 @@ static void printArgLine(QTextStream & ts, const char * smallArg,
 						  const char* fullArg, const QString desc)
 {
 	const char* lineformat = "  %1, %2 %3";
-	const int saw = 3;   // Short argument width
+	const int saw = 4;   // Short argument width
 	const int aw = -18;   // Argument width (negative is left aligned)
 	QString line = QString(lineformat)
 		.arg(smallArg, saw)
@@ -387,25 +391,21 @@ void ScribusQApp::showUsage()
 	QTextStream ts(&f);
 	ts << tr("Usage: scribus [option ... ] [file]") ; endl(ts);
 	ts << tr("Options:") ; endl(ts);
-	printArgLine(ts, ARG_HELP_SHORT, ARG_HELP,
-		tr("Print help (this message) and exit") );
-	printArgLine(ts, ARG_LANG_SHORT, ARG_LANG,
-		tr("Uses xx as shortcut for a language, eg `en' or `de'") );
-	printArgLine(ts, ARG_AVAILLANG_SHORT, ARG_AVAILLANG,
-		tr("List the currently installed interface languages") );
-	printArgLine(ts, ARG_FONTINFO_SHORT, ARG_FONTINFO,
-		tr("Show information on the console when fonts are being loaded") );
-	printArgLine(ts, ARG_NOSPLASH_SHORT, ARG_NOSPLASH,
-		tr("Do not show the splashscreen on startup") );
-	printArgLine(ts, ARG_VERSION_SHORT, ARG_VERSION,
-		tr("Output version information and exit") );
-	printArgLine(ts, ARG_SWAPDIABUTTONS_SHORT, ARG_SWAPDIABUTTONS,
-		tr("Use right to left dialog button ordering (eg. Cancel/No/Yes instead of Yes/No/Cancel)") );
-	printArgLine(ts, ARG_PREFS_SHORT, QString(ARG_PREFS)+" " + tr("filename"),
-		tr("Use filename as path for user given preferences") );
+	printArgLine(ts, ARG_FONTINFO_SHORT, ARG_FONTINFO, tr("Show information on the console when fonts are being loaded") );
+	printArgLine(ts, ARG_HELP_SHORT, ARG_HELP, tr("Print help (this message) and exit") );
+	printArgLine(ts, ARG_LANG_SHORT, ARG_LANG, tr("Uses xx as shortcut for a language, eg `en' or `de'") );
+	printArgLine(ts, ARG_AVAILLANG_SHORT, ARG_AVAILLANG, tr("List the currently installed interface languages") );
+	printArgLine(ts, ARG_NOSPLASH_SHORT, ARG_NOSPLASH, tr("Do not show the splashscreen on startup") );
+	printArgLine(ts, ARG_NEVERSPLASH_SHORT, ARG_NEVERSPLASH, tr("Stop the showing of the splashscreen on startup. Writes an empty file called .neversplash in ~/.scribus.") );
+	printArgLine(ts, ARG_PREFS_SHORT, QString(ARG_PREFS)+" "+ tr("filename"), tr("Use filename as path for user given preferences") );
+	printArgLine(ts, ARG_PROFILEINFO_SHORT, ARG_PROFILEINFO, tr("Show location ICC profile information on console while starting") );
+	printArgLine(ts, ARG_SWAPDIABUTTONS_SHORT, ARG_SWAPDIABUTTONS, tr("Use right to left dialog button ordering (eg. Cancel/No/Yes instead of Yes/No/Cancel)") );
+	printArgLine(ts, ARG_UPGRADECHECK_SHORT, ARG_UPGRADECHECK, tr("Download a file from the Scribus website and show the latest available version.") );
+	printArgLine(ts, ARG_VERSION_SHORT, ARG_VERSION, tr("Output version information and exit") );
+	
+	
 #if defined(_WIN32) && !defined(_CONSOLE)
-	printArgLine(ts, ARG_CONSOLE_SHORT, ARG_CONSOLE,
-		tr("Display a console window") );
+	printArgLine(ts, ARG_CONSOLE_SHORT, ARG_CONSOLE, tr("Display a console window") );
 #endif
 /* Delete me?
 	std::cout << "-file|-- name Open file 'name'" ; endl(ts);
@@ -458,53 +458,29 @@ void ScribusQApp::showHeader()
 	endl(ts);
 }
 
-bool ScribusQApp::usingGUI() const
+void ScribusQApp::neverSplash(bool splashOff)
 {
-	return useGUI;
+	QString prefsDir = ScPaths::getApplicationDataDir();
+	QFile ns(prefsDir+"/.neversplash");
+	if (splashOff)
+	{
+		if (QFileInfo(QDir::homeDirPath()).exists())
+		{
+			QDir prefsDirectory(prefsDir);
+			if (!QFileInfo(prefsDir).exists())
+				prefsDirectory.mkdir(prefsDir);
+			if (!ns.exists() && ns.open(IO_WriteOnly))
+				ns.close();
+		}
+	}
+	else
+	{
+		if (neverSplashExists())
+			ns.remove();
+	}
 }
 
-bool ScribusQApp::isMacGUI() const
+bool ScribusQApp::neverSplashExists()
 {
-	// Do it statically for now
-#if defined(Q_WS_MAC)
-	return true;
-#else
-	return false;
-#endif
+	return QFileInfo(ScPaths::getApplicationDataDir() + ".neversplash").exists();
 }
-
-bool ScribusQApp::isWinGUI() const
-{
-	// Do it statically for now
-#if defined(_WIN32)
-	return true;
-#else
-	return false;
-#endif
-}
-
-bool ScribusQApp::reverseDialogButtons() const
-{
-	if (swapDialogButtonOrder)
-		return true;
-	//Win32 - dont switch
-	#if defined(_WIN32)
-		return false;
-	//Mac Aqua - switch
-	#elif defined(Q_WS_MAC)
-		return true;
-	#else
-	//Gnome - switch
-	QString gnomesession= ::getenv("GNOME_DESKTOP_SESSION_ID");
-	if (!gnomesession.isEmpty())
-		return true;
-
-	//KDE/KDE Aqua - dont switch
-	//Best guess for now if we are running under KDE
-	QString kdesession= ::getenv("KDE_FULL_SESSION");
-	if (!kdesession.isEmpty())
-		return false;
-	#endif
-	return false;
-}
-
