@@ -96,7 +96,7 @@ void TOCIndexPrefs::languageChange()
 	tocParagraphStyleLabel->setText( tr( "Paragraph Style:" ) );
 	tocDestFrameLabel->setText( tr( "Destination Frame:" ) );
 	tabTOCIndexWidget->changeTab( tab, tr( "Table Of Contents" ) );
-//	tabTOCIndexWidget->changeTab( tab_2, tr( "Inde&x" ) );
+// 	tabTOCIndexWidget->changeTab( tab_2, tr( "Inde&x" ) );
 }
 
 void TOCIndexPrefs::init()
@@ -104,11 +104,11 @@ void TOCIndexPrefs::init()
 	disconnect( tocListBox, SIGNAL( highlighted(int) ), this, SLOT( selectToC(int) ) );
 	trStrNone=tr("None");
 	strNone=CommonStrings::None;
-	trStrPNBeginning= tr("At the beginning");
+	trStrPNBeginning=tr("At the beginning");
 	strPNBeginning="At the beginning";
-	trStrPNEnd= tr("At the end");
+	trStrPNEnd=tr("At the end");
 	strPNEnd="At the end";
-	trStrPNNotShown= tr("Not Shown");
+	trStrPNNotShown=tr("Not Shown");
 	strPNNotShown="Not Shown";
 
 	itemNumberPlacementComboBox->clear();
@@ -276,10 +276,10 @@ void TOCIndexPrefs::updateParagraphStyleComboBox()
 	paragraphStyleList.clear();
 	paragraphStyleList.append(trStrNone);
 
-	if(currDoc!=NULL && currDoc->docParagraphStyles.count()>5)
+	if(currDoc!=NULL) // && currDoc->docParagraphStyles.count()>5)
 	{
-		for (uint i = 5; i < currDoc->docParagraphStyles.count(); ++i)
-			paragraphStyleList.append(currDoc->docParagraphStyles[i].Vname);
+		for (uint i = 0; i < currDoc->paragraphStyles().count(); ++i)
+			paragraphStyleList.append(currDoc->paragraphStyles()[i].name());
 	}
 	itemParagraphStyleComboBox->clear();
 	itemParagraphStyleComboBox->insertStringList(paragraphStyleList);
@@ -305,9 +305,12 @@ void TOCIndexPrefs::deleteToC()
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		localToCSetupVector.erase(it);
 		updateToCListBox();
 		enableGUIWidgets();
@@ -321,9 +324,12 @@ void TOCIndexPrefs::itemAttributeSelected( const QString& itemAttributeName )
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		if (itemAttributeName==trStrNone)
 			(*it).itemAttrName=strNone;
 		else
@@ -338,9 +344,12 @@ void TOCIndexPrefs::itemFrameSelected( const QString& frameName )
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		if (frameName==trStrNone)
 			(*it).frameName=strNone;
 		else
@@ -356,9 +365,12 @@ void TOCIndexPrefs::itemPageNumberPlacedSelected( const QString& pageLocation )
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		if (pageLocation==trStrPNBeginning || pageLocation==strPNBeginning)
 			(*it).pageLocation=Beginning;
 		else
@@ -376,9 +388,12 @@ void TOCIndexPrefs::itemParagraphStyleSelected( const QString& itemStyle )
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		if (itemStyle==trStrNone)
 			(*it).textStyle=strNone;
 		else
@@ -399,9 +414,12 @@ void TOCIndexPrefs::setToCName( const QString &newName )
 	{
 		tocListBox->changeItem(newName, numberSelected);
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		(*it).name=newName;
 	}
 }
@@ -413,9 +431,12 @@ void TOCIndexPrefs::nonPrintingFramesSelected( bool showNonPrinting )
 	if (numberSelected>=0)
 	{
 		int i=0;
-		ToCSetupVector::Iterator it;
-		for(it = localToCSetupVector.begin(); it!= localToCSetupVector.end(), i<numberSelected ; ++it, ++i)
-			;
+		ToCSetupVector::Iterator it=localToCSetupVector.begin();
+		while (it!= localToCSetupVector.end() && i<numberSelected)
+		{
+			++it;
+			++i;
+		}
 		(*it).listNonPrintingFrames=showNonPrinting;
 	}
 }
